const fs = require('fs');
const path = require('path');
const request = require('request');

// 维持cookie状态的
const r = request.defaults({ jar: true });

// API
const UPLOAD_API = 'https://upload.api.cli.im/upload.php?kid=cliim';
const REC_API = 'https://cli.im/apis/up/deqrimg';
const REC_PAGE = 'https://cli.im/deqr/';

// 上传图片
function uploadQR(imgPath) {
  return new Promise((resolve, reject) => {
    const formData = {
      Filedata: fs.createReadStream(imgPath)
    };
    r({
      url: UPLOAD_API,
      method: 'POST',
      headers: {
        'X-Requested-With': 'XMLHttpRequest',
        'Referer': 'https://cli.im/deqr/',
        'User-Agent': 'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/62.0.3202.94 Safari/537.36'
      },
      formData
    }, (err, response, body) => {
      if (err) {
        reject()
      } else {
        const matches = decodeURIComponent(body).match(/#([^>]*)">/);
        if (matches && matches.length) {
          try {
            const ret = JSON.parse(decodeURIComponent(matches[1]));
            if (ret && ret.data && ret.data.path) {
              resolve(ret.data.path);
            } else {
              reject();
            }
          } catch (err) {
            reject(err);
          }
        } else {
          reject();
        }
      }
    });
  });
}

// 识别图片
function recQR(imgUrl) {
  return new Promise((resolve, reject) => {
    r({
      url: REC_API,
      method: 'POST',
      headers: {
        'X-Requested-With': 'XMLHttpRequest',
        'Referer': 'https://cli.im/deqr/',
        'User-Agent': 'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/62.0.3202.94 Safari/537.36'
      },
      formData: {
        img: imgUrl
      }
    }, function(err, response, body) {
      if (err) {
        reject();
      } else {
        try {
          const ret = JSON.parse(body);
          if (ret && ret.info && ret.info.data) {
            resolve(ret.info.data);
          } else {
            reject();
          }
        } catch (err) {
          reject(err);
        }
      }
    });
  });
}

module.exports = (imgPath) => {
  return uploadQR(imgPath)
      .then(recQR);
};